
# Madan
--------

Madan is an end-to-end open source platform for math,machine learning,Computer Vision, and Natural Language Processing. It has a comprehensive, flexible ecosystem of tools, libraries, and community resources that lets researchers push the state-of-the-art in AI and developers easily build and deploy AI-powered applications.


-------
## Install

To install the current release
```
$ pip install madan
```
To update madan to the latest version, add --upgrade flag to the above commands.


## Latest update on library
### 1. Math
### 2. Machine learning
### 3. Computer Vision
On function that computes the object detection, depth of the object, face recognition, and object tracking.
    <img src="https://github.com/MadanBaduwal/MadanBaduwal.github.io/blob/main/images/2.cv.gif" alt="GitHub badge" />

### 5. Natural Language Processing


